@@ -7,6 +7,7 @@ library(hereR)
 library(mapview)
 library(sf)
 mapviewOptions(
+  fgb = FALSE,
   vector.palette = colorRampPalette(
     c("#000004FF", "#420A68FF", "#932667FF", "#DD513AFF", "#FCA50AFF", "#FCFFA4FF")
   )
@@ -25,13 +26,13 @@ stations <- hereR:::example$station
 ## ----table_connection_section, eval=TRUE, echo=FALSE, out.width='100%', fig.align='center', screenshot.force=FALSE----
 knitr::kable(head(as.data.frame(connection_section)[, colnames(connection_section) != "geometry"]), format = "html")
 
-## ----pt_connection_section_map, eval=TRUE, out.width='100%'-------------------
-mapview(connection_section,
-        zcol = "mode",
-        layer.name = "Transport mode",
-        map.types = c("Esri.WorldTopoMap"),
-        homebutton = FALSE
-)
+## ----pt_connection_section_map, eval=FALSE, out.width='100%'------------------
+#  mapview(connection_section,
+#          zcol = "mode",
+#          layer.name = "Transport mode",
+#          map.types = c("Esri.WorldTopoMap"),
+#          homebutton = FALSE
+#  )
 
 ## ----pt_connection_summary, eval = FALSE--------------------------------------
 #  connection_summary <- connection(
@@ -51,9 +52,6 @@ knitr::kable(head(as.data.frame(connection_summary)[, colnames(connection_summar
 #  )
 
 ## ----stations_map, eval=FALSE, out.width='100%'-------------------------------
-#  # NOTE: This code block is temporarily not evaluated due to an issue of the
-#  # mapview package when plotting multiple SF layers with the new CRS structure of
-#  # version 0.9-0 (see: https://github.com/r-spatial/mapview/issues/271).
 #  buffer <-
 #    poi %>%
 #    st_transform(2056) %>%
