@@ -7,6 +7,7 @@ library(hereR)
 library(mapview)
 library(ggplot2)
 mapviewOptions(
+  fgb = FALSE,
   vector.palette = colorRampPalette(
     c("#0571B0", "#92C5DE", "#F7F7F7","#F4A582", "#CA0020")
   )
@@ -29,9 +30,6 @@ cols <- c("station", "distance", "description",
 knitr::kable(as.data.frame(observation)[, cols], format = "html")
 
 ## ----map_obs, eval=FALSE, out.width='100%'------------------------------------
-#  # NOTE: This code block is temporarily not evaluated due to an issue of the
-#  # mapview package when plotting multiple SF layers with the new CRS structure of
-#  # version 0.9-0 (see: https://github.com/r-spatial/mapview/issues/271).
 #  m <-
 #    mapview(observation,
 #            zcol = "temperature",
@@ -74,9 +72,6 @@ g <- lapply(1:nrow(forecast), function(x) {
 })
 
 ## ----map_forecast, eval=FALSE, out.width='100%'-------------------------------
-#  # NOTE: This code block is temporarily not evaluated due to an issue of the
-#  # mapview package when plotting multiple SF layers with the new CRS structure of
-#  # version 0.9-0 (see: https://github.com/r-spatial/mapview/issues/271).
 #  m <-
 #    mapview(forecast,
 #            color = "black",
